@@ -890,7 +890,10 @@ def _verify_signature(
                 # If the variable is in runtime.kwonly, it's just mislabelled as not a
                 # keyword-only argument
                 if stub_arg.variable.name not in runtime.kwonly:
-                    yield f'runtime does not have argument "{stub_arg.variable.name}"'
+                    msg = f'runtime does not have argument "{stub_arg.variable.name}"'
+                    if runtime.varkw is not None:
+                        msg += ". Maybe you forgot to make it keyword-only in the stub?"
+                    yield msg
                 else:
                     yield f'stub argument "{stub_arg.variable.name}" is not keyword-only'
             if stub.varpos is not None:
@@ -1686,7 +1689,7 @@ def get_importable_stdlib_modules() -> set[str]:
                 modules_by_finder[m.module_finder].add(m.name)
         for finder, module_group in modules_by_finder.items():
             if (
-                "site-packages" not in Path(finder.path).parents
+                "site-packages" not in Path(finder.path).parts
                 # if "_queue" is present, it's most likely the module finder
                 # for stdlib extension modules;
                 # if "queue" is present, it's most likely the module finder
